============================
Django AlphaFilter |version|
============================

Contents:

.. toctree::
   :maxdepth: 2
   
   installation
   getting_started
   default_alphabet
   templatetag
   reference/index


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

